@@ -16,20 +16,25 @@ def configure():
 
 # Creating command 
 @configure.command(name='configure')
-def configure():
+@click.option('--env','-e', required=False)
+def configure(env):
     """If this command is run with no arguments, you will be prompted for configuration values such as your User ID, Client ID and Client Secret ID.If your configure file does not  exist
-       (the default location is ~/.aitest/configure), the aitest CLI will create it for you.To keep an existing value, hit enter when prompted for the value.
-
+       (the default location is ~/.aitest/prod/configure), the aitest CLI will create it for you.To keep an existing value, hit enter when prompted for the value.
+        Default Environment is PROD
        To save the configurations , you can run below command:\n
-       aitest configure
+       aitest configure -e [aitest enviornment (dev/prod)]
               
     """
     user_id = input('Enter aiTest User Identifier :')
     client_id = input('Enter Client ID :')
     client_secret_id = input('Enter Client Secret ID :')
 
+    if env and env == 'dev':
+        profile = 'dev'
+    else:
+        profile = 'prod'
 
-    folder_path =os.path.join( os.path.expanduser('~'),".aitest" )
+    folder_path =os.path.join( os.path.expanduser('~'),(".aitest/{}".format(profile)))
     folder_exist = os.path.exists(folder_path)
     if not folder_exist:
         os.mkdir(folder_path)
@@ -51,7 +56,7 @@ def configure():
             fd.write("client_secret_id = "+" "+"\n")
         fd.close()
     else:
-        file_path =os.path.join( os.path.expanduser('~'),".aitest","configure" )
+        file_path =os.path.join( os.path.expanduser('~'),(".aitest/{}".format(profile)),"configure" )
         file = open(file_path,"r")
         content = file.read()
         data = content.split("\n")
@@ -86,19 +91,25 @@ def run():
 @click.option('--testrun_id','-id', required=True)
 @click.option('--wait_time','-w',required=False)
 @click.option('--git_pass','-p', required=False)
-def run(testrun_id, git_pass, wait_time):
+@click.option('--env','-e',required=False)
+def run(testrun_id, git_pass, wait_time,env):
     """If this command is run with testrun id as an argument, aitest CLI will create new test for you with same configuration of provided testrun id.Enter git password with -p only if you used git url of the automation code for creating the test otherwise no need to enter git password.
        Enter the waiting time in minutes with -w as an argument, To wait for looking the testrun status in given time.\n
+       Default Environment is PROD
        To re-run the test, you can run below command:\n
-       aitest run -id [testrun id] -p [git password] -w [wait_time]
-    """    
+       aitest run -id [testrun id] -p [git password] -w [wait_time] -e [aitest enviornment (dev/prod)]
+    """
+    if env and env == 'dev':
+        profile = 'dev'
+    else:
+        profile='prod'
     try: 
         if os.environ["USER_ID"] and os.environ["CLIENT_ID"] and os.environ["CLIENT_SECRET_ID"]:
             user_id = os.environ["USER_ID"]
             client_id = os.environ["CLIENT_ID"]
             client_secret_id=os.environ["CLIENT_SECRET_ID"]
         else:     
-            file_path =os.path.join( os.path.expanduser('~'),".aitest","configure" )
+            file_path =os.path.join( os.path.expanduser('~'),(".aitest/{}".format(profile)),"configure" )
             file = open(file_path,"r")
             content = file.read()
             data = content.split("\n")
@@ -116,19 +127,19 @@ def run(testrun_id, git_pass, wait_time):
     encoded_value = encoded_str.decode('utf-8')
 
     access_token_api_headers = {"Authorization":f"Basic {encoded_value}", "content-type": "application/x-www-form-urlencoded"}
-   
-    access_token_api = "https://login-marxeed-dev.auth.us-east-1.amazoncognito.com/oauth2/token"
+
+    if profile == 'dev':
+        access_token_api = "https://login-marxeed-dev.auth.us-east-1.amazoncognito.com/oauth2/token"
+    else:
+        access_token_api = "https://login.aaic.cc/oauth2/token"
 
 
     data = { 'grant_type': 'client_credentials', 'scope': 'aitestpublic/runtest' }
 
-
     token = requests.post(access_token_api,headers=access_token_api_headers,data=data)
     if token.status_code==400:
         click.echo('\n"error" : "Please add your valid Client ID and Client Secret ID ."\n')
         exit()
-
-        
     else:
         token_data = token.json()
 
@@ -136,12 +147,14 @@ def run(testrun_id, git_pass, wait_time):
   
     headers = {"Authorization": f"Bearer {access_token}", "aiTest-User-Identifier":user_id}
 
-    base_url = "https://api.aitest.dev.appliedaiconsulting.com/public/v1/testrun/load_test"
+    if profile=='dev':
+        base_url= "https://api.aitest.dev.appliedaiconsulting.com/public/v1/testrun/load_test"
+    else:
+        base_url = "https://api.aitest.appliedaiconsulting.com/public/v1/testrun/load_test"
 
     dd = {"testrun_id":testrun_id, "git_password":git_pass}
     
     payload=json.dumps(dd)
-   
 
     res2 =requests.post(base_url,data=payload,headers=headers)
     if res2.status_code==401:
@@ -154,7 +167,21 @@ def run(testrun_id, git_pass, wait_time):
         except:
             click.echo(res_body)
             exit(-1)
+        project_id=test_data['load_test_details']['project_id']
+        test_type=test_data['load_test_details']['test_type']
+        if test_type == 'functional_test':
+            sub_link='multi-browser-test'
+        elif test_type == 'load_test':
+            sub_link='performance-test'
+        else:
+            sub_link='url-test'
+        if profile == 'dev':
+            aitest_ui="https://app.aitest.dev.appliedaiconsulting.com/"
+        else:
+            aitest_ui="https://app.aitest.appliedaiconsulting.com/"
+        testrun_link=aitest_ui+sub_link+"?testrun_id="+testrun_id+"&project_id="+project_id
         click.echo(f"\nTestrun created successfully\nTestrun Name : {test_data['load_test_details']['testrun_name']}\nTestrun ID : {test_data['load_test_details']['testrun_id']}\n")
+        click.echo(f"\nTestrun Link: {testrun_link}\n")
         if wait_time:
             click.echo("Testrun is in progress, result will be displayed once it get completed.")
             new_time = datetime.now() +timedelta(minutes=int(wait_time))
@@ -163,7 +190,10 @@ def run(testrun_id, git_pass, wait_time):
                 if (new_time.strftime("%H:%M:%S"))==(datetime.now().strftime("%H:%M:%S")):
                     click.echo(f"The request is timed out. The testrun is still in progress. To see the status of the testrun, please run command : [ aitest status {test_data['load_test_details']['testrun_id']} ].")
                     exit()
-                base_url = f"https://api.aitest.dev.appliedaiconsulting.com/public/v1/testrun_result/status/{test_data['load_test_details']['testrun_id']}"
+                if profile=='dev':
+                    base_url = f"https://api.aitest.dev.appliedaiconsulting.com/public/v1/testrun_result/status/{test_data['load_test_details']['testrun_id']}"
+                else:
+                    base_url = f"https://api.aitest.appliedaiconsulting.com/public/v1/testrun_result/status/{test_data['load_test_details']['testrun_id']}"
                 status_res =requests.get(base_url,headers=headers)
                 status_test_data=status_res.json()
                 if status_test_data['statusCode'] == 200:
@@ -186,8 +216,7 @@ def run(testrun_id, git_pass, wait_time):
                         exit()
                     else: 
                         click.echo(f"{fail_count} test cases from this testrun have failed. Please refer above table for more details.")
-                        exit(1)   
-
+                        exit(1)
     else:
         click.echo(res2.json())
         exit()
@@ -201,18 +230,24 @@ def status():
 # Creating command
 @status.command(name='status')
 @click.option('--testrun_id','-id', required=True)
-def status(testrun_id):
+@click.option('--env','-e', required=False)
+def status(testrun_id,env):
     """ If this command is run with testrun id as an argument, aitest CLI will display the test details .\n  
+        Default Environment is PROD
         To see the status of test , you can run below command:\n
-        aitest status -id [testrun_id]
+        aitest status -id [testrun_id] -e [aitest enviornment (dev/prod)]
     """
+    if env and env=='dev':
+        profile='dev'
+    else:
+        profile='prod'
     try: 
         if os.environ["USER_ID"] and os.environ["CLIENT_ID"] and os.environ["CLIENT_SECRET_ID"]:
             user_id = os.environ["USER_ID"]
             client_id = os.environ["CLIENT_ID"]
             client_secret_id=os.environ["CLIENT_SECRET_ID"]
         else:     
-            file_path =os.path.join( os.path.expanduser('~'),".aitest","configure" )
+            file_path =os.path.join( os.path.expanduser('~'),(".aitest/{}".format(profile)),"configure" )
             file = open(file_path,"r")
             content = file.read()
             data = content.split("\n")
@@ -231,9 +266,11 @@ def status(testrun_id):
     encoded_value = encoded_str.decode('utf-8')
 
     access_token_api_headers = {"Authorization":f"Basic {encoded_value}", "content-type": "application/x-www-form-urlencoded"}
-   
-    access_token_api = "https://login-marxeed-dev.auth.us-east-1.amazoncognito.com/oauth2/token"
 
+    if profile == 'dev':
+        access_token_api = "https://login-marxeed-dev.auth.us-east-1.amazoncognito.com/oauth2/token"
+    else:
+        access_token_api = "https://login.aaic.cc/oauth2/token"
 
     data = { 'grant_type': 'client_credentials', 'scope': 'aitestpublic/runtest' }
 
@@ -247,7 +284,10 @@ def status(testrun_id):
     access_token=token_data["access_token"]
 
     headers = {"Authorization": f"Bearer {access_token}", "aiTest-User-Identifier":user_id}
-    base_url = f"https://api.aitest.dev.appliedaiconsulting.com/public/v1/testrun_result/status/{testrun_id}"
+    if profile=='dev':
+        base_url = f"https://api.aitest.dev.appliedaiconsulting.com/public/v1/testrun_result/status/{testrun_id}"
+    else:
+        base_url = f"https://api.aitest.appliedaiconsulting.com/public/v1/testrun_result/status/{testrun_id}"
 
     status_res =requests.get(base_url,headers=headers)
     if status_res.status_code==401:
